@@ -6,7 +6,8 @@ void ConnectionsConsumer::run()
 
         // when logging in Conntrack-mode or Device-mode (realTime)
         // inspect the TTL of the incoming packages in the background.
-    if (d_options.realTime())
+    bool realTime = Options::instance().realTime();
+    if (realTime)
         cleanupThread = thread{ &ConnectionsConsumer::cleanupWrap, this };
 
     while (true)
@@ -33,7 +34,7 @@ void ConnectionsConsumer::run()
         d_handler[record->protocol()]->process( RecordPtr{ record } );  
     }
 
-    if (d_options.realTime())
+    if (realTime)
         cleanupThread.join();
         
     time_t eop = time(0) + 1;
