@@ -4,8 +4,8 @@ void IPbase::destroy(Record const &record)
 {                                       // find this record's accumulated data
     auto iter = find(record.key());
 
-    if (iter == end())                  // unknown record: no existing
-        throw false;                    // connection
+    if (iter == end())                  // unknown record
+        return;
 
     auto &accu = iter->second;
 
