@@ -13,17 +13,14 @@ void IPbase::logConnection(Record const &record) const
                                 left << setw(5) << record.sourcePort();
 
         (this->*d_via)(record);
+        (this->*d_dst)(record);
 
-        d_stdMsg << " "
-            "to " << record.destIPstr() << ',' <<  
-                                showLeft(record.destPort()) << right;
+        d_stdMsg << right;
 
         (this->*d_byteCounts)(record);
 
         d_stdMsg << s_logTypeText[s_logType].first << endl;
 
-        logCSV(record);
+        logCSV(record);         // calls *d_logData -> logData()
     }
 }
-
-
