@@ -5,6 +5,7 @@
 
 #include <bobcat/fork>
 #include <bobcat/multibuf>
+#include <bobcat/signal>
 
 #include "../options/options.h"
 #include "../rotatingstream/rotatingstream.h"
@@ -17,7 +18,7 @@ namespace FBB
 class Producer;
 class Storage;
 
-class NatFork: public FBB::Fork
+class NatFork: public FBB::Fork, public FBB::SignalHandler
 {
     Options &d_options;
 
@@ -54,7 +55,7 @@ class NatFork: public FBB::Fork
         void childProcess() override;
 
         void cleanupPidFile() const;
-
+        void signalHandler(size_t signum)   override;
 };
         
 #endif
