@@ -1,5 +1,9 @@
 #include "natfork.ih"
 
+//f: NatFork::run()
+    //c: NatFork::childProcess()
+    //c: NatFork::parentProcess()
+
 void NatFork::run()
 {
     switch (d_mode)
@@ -9,16 +13,9 @@ void NatFork::run()
         break;
 
         case Options::DEVICE:
-        break;
-
         case Options::TCPDUMP:
-            if (d_options.daemon())
-                d_stdMsg << 
-                        "TCPDUMP processing cannot be used in daemon mode" <<
-                        endl;
         break;
     }
-
     
     if (d_options.daemon())
         fork();
