@@ -7,9 +7,9 @@ void NatFork::setupDaemonMsg()
         imsg.off();
         return;
     }
-                                // verbose msg via syslog, if syslog is active
+                                // verbose msg via multiStreambuf
     if (d_options.verbose())
-        imsg.reset(*d_syslog);
+        imsg.reset(&d_multiStreambuf);
     else
         imsg.off();
 }
