@@ -33,5 +33,5 @@ try
 }
 catch (int)
 {
-    throw Exception() << "cannot retrieve NIC info for `" << name << '\'';
+    throw Exception{} << "cannot retrieve NIC info for `" << name << '\'';
 }
