@@ -44,13 +44,16 @@ struct Options: public IP_Types
 
     private:
         FBB::ArgConfig &d_arg;
-    
+  
+        bool d_byteCounts;  
         bool d_daemon;
+        bool d_debug;
+        bool d_rotate;
+        bool d_rotateData;
+        bool d_showDst;
+        bool d_showVia;
         bool d_stdout;
         bool d_terminate;
-        bool d_debug;
-        bool d_showVia;
-        bool d_showBytes;
         
         Mode d_mode;
 
@@ -63,6 +66,8 @@ struct Options: public IP_Types
         std::string d_rotateTimeSpec;   // e.g., ' minutes'
 
         size_t d_nRotations = 0;        // rotate #files
+        size_t d_rotationInterval;      // minimum interval in secs. between 
+                                        // log-file rotations
 
         time_t d_ttl = TTL;
         time_t d_ttlTCP = TTL_TCP;
@@ -119,17 +124,20 @@ struct Options: public IP_Types
 
         bool realTime() const;          // true if the packets are received
                                         // real-time; when recorded: false.
-        bool stdout() const;
-        bool kill() const;
+        bool byteCounts() const;
         bool debug() const;
+        bool forwardOption() const;     // requested terminate, rotate(Data) 
+        bool showDst() const;
         bool showVia() const;
-        bool showBytes() const;
+        bool stdout() const;
 
         size_t IPheaderSize() const;
         size_t verbose() const;
 
-        size_t rotateFreq() const;
+        size_t rotateFreq() const;          // 0: no log rotation requested
         size_t rotateFactor() const;
+        size_t rotationInterval() const;    // seconds, smallest aceptable
+                                            // rotation interval
         size_t nRotations() const;
         std::string const &rotateTimeSpec() const;
 
@@ -145,7 +153,8 @@ struct Options: public IP_Types
         std::string const &pidFile() const;
         std::unordered_set<Protocol> const &protocolSet() const;
         bool hasProtocol(std::string const &protoName) const;
-        bool hasProtocol(size_t protocol) const;
+        bool hasProtocol(size_t protocol) const;    // arg: a protocol value:
+                                                    // IPTypes: ICMP, TCP, UDP
         std::string const &conntrackCommand() const;
         char const *conntrackDevice() const;
         std::string const &syslogTag() const;
@@ -182,7 +191,11 @@ struct Options: public IP_Types
     private:
         Options();
 
+        bool kill() const;
         void openConfig();
+        size_t readPid() const;
+        bool rotate() const;            // sends SIGHUP
+        bool rotateData() const;        // sends SIGSTOP
         void setBoolMembers();
         void setConntrack();
         void setMode();
@@ -194,246 +207,6 @@ struct Options: public IP_Types
         void setProtocol();
 };
 
-inline Options::Mode Options::mode() const
-{   
-    return d_mode;
-}
-
-inline bool Options::realTime() const
-{
-    return d_mode != TCPDUMP;
-}
-
-inline bool Options::stdout() const
-{   
-    return d_stdout;
-}
-
-inline bool Options::debug() const
-{   
-    return d_debug;
-}
-
-inline bool Options::showVia() const
-{   
-    return d_showVia;
-}
-
-inline bool Options::showBytes() const
-{   
-    return d_showBytes;
-}
-
-inline size_t Options::verbose() const
-{   
-    return d_verbose;
-}
-
-inline bool Options::daemon() const
-{   
-    return d_daemon;
-}
-
-inline void Options::foreground()
-{   
-    d_daemon = false;
-}
-
-inline std::string const &Options::log() const
-{   
-    return d_log;
-}
-
-inline size_t Options::rotateFreq() const
-{
-    return d_rotateFreq;
-}
-
-inline size_t Options::rotateFactor() const
-{
-    return d_rotateFactor;
-}
-
-inline std::string const &Options::rotateTimeSpec() const
-{
-    return d_rotateTimeSpec;
-}
-
-inline size_t Options::nRotations() const
-{
-    return d_nRotations;
-}
-
-inline time_t Options::ttl() const
-{
-    return d_ttl;
-}
-
-inline time_t Options::ttlTCP() const
-{
-    return d_ttlTCP;
-}
-
-inline size_t Options::IPheaderSize() const
-{
-    return d_IPheaderSize;
-}
-
-inline Options::Time Options::time() const
-{   
-    return d_time->second;
-}
-
-inline std::string const &Options::timeTxt() const
-{   
-    return d_time->first;
-}
-
-inline std::string const &Options::configPath() const
-{   
-    return d_configPath;
-}
-
-inline std::string const &Options::syslogTag() const
-{   
-    return d_syslogTag;
-}
-
-inline std::string const &Options::logData() const
-{   
-    return d_logData;
-}
-
-//inline size_t Options::logDataFlush() const
-//{   
-//    return d_logDataFlush;
-//}
-
-inline std::string const &Options::pidFile() const
-{   
-    return d_PIDfile;
-}
-
-inline std::string const &Options::timeSpecError() const
-{   
-    return d_timeSpecError;
-}
-
-inline FBB::Priority Options::syslogPriority() const
-{   
-    return d_syslogPriority->second;
-}
-
-inline std::string const &Options::priority() const
-{   
-    return d_syslogPriority->first;
-}
-
-inline std::string Options::syslogPriorityError() const
-{   
-    return d_syslogPriorityError;
-}
-
-inline FBB::Facility Options::syslogFacility() const
-{   
-    return d_syslogFacility->second;
-}
-
-inline std::string Options::syslogFacilityError() const
-{   
-    return d_syslogFacilityError;
-}
-
-inline char const *Options::defaultPIDfile() 
-{
-    return s_defaultPIDfile;
-}
-
-inline char const *Options::defaultConfigPath() 
-{
-    return s_defaultConfigPath;
-}
-
-inline std::string const &Options::facility() const
-{   
-    return d_syslogFacility->first;
-}
-
-inline std::string const &Options::conntrackCommand() const
-{
-    return d_conntrackCommand;
-}
-
-inline char const *Options::conntrackDevice() const
-{
-    return d_conntrackDevice.c_str();
-}
-
-inline char const *Options::operator[](size_t idx) const
-{
-    return d_arg[idx];
-}
-
-inline size_t Options::nArgs() const
-{
-    return d_arg.nArgs();
-}
-
-inline std::string const &Options::basename() const
-{
-    return d_arg.basename();
-}
-
-inline char const *Options::defaultConntrackArgs()
-{
-    return s_defaultConntrackArgs;
-}
-
-inline char const *Options::defaultConntrackCommand() 
-{
-    return s_defaultConntrackCommand;
-}
-
-inline char const *Options::defaultConntrackDevice() 
-{
-    return s_defaultConntrackDevice;
-}
-
-inline char const *Options::defaultSyslogIdent() 
-{
-    return s_defaultSyslogIdent;
-}
-
-inline char const *Options::defaultSyslogFacility() 
-{
-    return s_defaultSyslogFacility;
-}
-
-inline char const *Options::defaultSyslogPriority() 
-{
-    return s_defaultSyslogPriority;
-}
-
-inline size_t Options::conntrackRestart() const
-{
-    return d_conntrackRestart;
-}
-
-inline std::unordered_set<IP_Types::Protocol> const &Options::protocolSet() 
-                                                                        const
-{
-    return d_protocols;
-}
-
-inline std::string const &Options::protocolName(Protocol protocol)
-{
-    return s_protocol2name.find(protocol)->second;
-}
-
-inline bool Options::hasProtocol(size_t protocol) const
-{
-    return d_protocols.find(static_cast<Protocol>(protocol))
-            != d_protocols.end(); 
-}
+#include "options.f"
 
 #endif
