@@ -10,8 +10,11 @@ void Options::setConntrack()
         (d_conntrackCommand = s_defaultConntrackCommand) += 
                                                  s_defaultConntrackArgs; 
 
-    d_conntrackCommand +=
-            (
+        // when multiple protocols are specified, conntrack's command does
+        // not receive a -p setting, but the conntrack records only handle
+        // the specified protocols.
+    d_conntrackCommand +=           // by default: all protocols, otherwise
+            (                       // use the specified protocol
                 d_protocols.size() == 1 ? 
                     " -p " + 
                         s_protocol2name.find(*d_protocols.begin())->second
