@@ -1,8 +1,7 @@
 #ifndef INCLUDED_PCAP_
 #define INCLUDED_PCAP_
 
-#include <iosfwd>
-#include <pcap/pcap.h>
+#include <pcap.h>
 
 class Pcap
 {
@@ -15,21 +14,15 @@ class Pcap
         Pcap(char const *device, bool promisc = false, size_t snapLen = 1500, 
              size_t timeOutMs = 1000);
 
-        void filter(std::string const &filterExpr, bool optimize = true);
-        void loop(u_char *user, pcap_handler callback);
+        void loop(void *pcapFilterPtr, pcap_handler callback);
         void stop();
-
         int shiftPacketBegin() const;
 
     private:
+        void filterProtocols();                 // filter interesting prot's.
         void computeShift(char const *device);  // from Pcap(): sets d_shift
 };
 
-inline void Pcap::stop()
-{
-    pcap_breakloop(d_pcap);
-}
-
 inline int Pcap::shiftPacketBegin() const
 {
     return d_shift;
