@@ -2,7 +2,8 @@
 
 void Record::addReceivedBytes(Record const &next)
 {
-    d_receivedBytes += next.payload();
+    // d_receivedBytes += next.payload();
+    d_receivedBytes += next.d_receivedBytes;
     
     setEndTime(next);
 }
