@@ -1,4 +1,6 @@
 #include "record.ih"
 
 Record::~Record()
-{}
+{
+    --s_count;
+}
