@@ -157,7 +157,7 @@ struct Record: public IP_Types
         void setEndTime(Record const &record);  // also updates d_lastUsed
         std::ostream &insertInto(std::ostream &out) const;
 
-        static char *ntoa(uint32_t ipAddr);
+        static std::string ntoa(uint32_t ipAddr);
 };
 
 typedef std::unique_ptr<Record> RecordPtr;
