@@ -2,7 +2,7 @@
 
 void RotatingStreambuf::notify()
 {
-    if (not s_rotate.empty())
+    if (rotationsRequested())
     {
         s_semaphore.notify();
         s_rotateThread.join();
