@@ -12,6 +12,8 @@ Where:
 
 
     char const ctCommand[] = R"(')
+      --conntrack-bytecounts: the `conntrack' program also reports the
+                           number of sent and received bytes  
       --conntrack-command cmd - cmd: `conntrack' program call (default 
                            `)"; 
 
@@ -38,9 +40,13 @@ Where:
                            `time[mhd]' or `time[mhd]nFiles' (m: minutes,
                            h: hours, d: days. By default (or if 'time' or
                            `nfiles' are zero) log files are not rotated.
+      --no-bytes         - sent and received numbers of bytes are not listed 
+                           in log-entries
       --no-daemon        - do not run )"; 
 
     char const pidFile[] = R"( in the background
+      --no-dst           - do not include 'dst' entries in the log file
+                           (default: 'dst' entries are included)
       --no-via           - do not include 'via' entries in the log file
                            (default: 'via' entries are included)
       --pid-file (-p) path - `path' is the name of the file holding the
@@ -51,8 +57,13 @@ Where:
       --protocol (-P) spec - spec: protocols handled by )"; 
 
 
-    char const optionS[] = R"(Use colon separated combinations of
+    char const optionRot[] = R"(Use colon separated combinations of
                            tcp (default), udp and icmp, or use `all'
+      --rotate           - the log-files of a separately running process are 
+                           rotated
+      --rotate-data      - the log-data files of a separately running )";
+
+    char const optionS[] = R"( process are rotated
       -S                 - systemd fix: specify this as first argument when
                            starting )"; 
 
@@ -128,6 +139,7 @@ void usage(std::string const &progname)
         noDaemon    << progname <<
         pidFile     << Options::defaultPIDfile() << 
         protocol    << progname <<
+        optionRot   << progname <<
         optionS     << progname <<
         syslogTag   << Options::defaultSyslogIdent() << 
         syslogFacil << Options::defaultSyslogFacility() << 
